UpSearchService class

Constructors

UpSearchService()

Properties

current → String?
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stream$ → Stream
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove() → dynamic
toString() → String
A string representation of this object.
inherited
update(dynamic newValue) → dynamic

Operators

operator ==(Object other) → bool
The equality operator.
inherited